==> claromentis-framework-8.13.65-b8aa1bfb.zip: web/intranet/core/classes/Http/ResponseFactory.php <==
<?php
namespace Claromentis\Core\Http;

$GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"] ?: array()) + array("_f73dab606630b388645c4f7d" . "3fbb13bb" => base64_decode("YXJyYXlfbWVyZ2" . "U="), "_19ab1d3c28df629" . "2f3bb65e6e28bcf6" . "b" => base64_decode("Q29udGVudC1" . "UeXBl"), "_50b7be803e435f67e0b8" . "6be1fb6ee7b5" => base64_decode("dGV4dC9o" . "dG1sOyBj" . "aGFyc2V0" . "PXV0Zi04"));
use Symfony\Component\HttpFoundation\Response;
class ResponseFactory
{
    public function GetTemplaterCallResponse(string $template, array $args, string $_678d945258a520c3df1c42fe4b558f34) : TemplaterCallResponse
    {
        return new TemplaterCallResponse($template, $args, $_678d945258a520c3df1c42fe4b558f34);
    }
    public function GetJsonPrettyResponse($data = null, int $status = 200, array $_3e258c4e6163007d8094c39647602e7a = []) : JsonPrettyResponse
    {
        return new JsonPrettyResponse($data, $status, $_3e258c4e6163007d8094c39647602e7a);
    }
    public function GetFileResponse(string $file_name, $_a75ddc6afa2b6058d9290bb9a8915e90, bool $_4b83d26c5eb0d93a0b377ff582df05e0 = false) : FileResponse
    {
        return new FileResponse($file_name, $_a75ddc6afa2b6058d9290bb9a8915e90, $_4b83d26c5eb0d93a0b377ff582df05e0);
    }
    public function GetFileStreamResponse($_1cc5aa2f679b575f82786a73f0da28f8, $file_name, $_4b83d26c5eb0d93a0b377ff582df05e0 = false, $_655a561f4e34bbdfa745dc13393471b3 = '') : FileStreamResponse
    {
        return new FileStreamResponse($_1cc5aa2f679b575f82786a73f0da28f8, $file_name, $_4b83d26c5eb0d93a0b377ff582df05e0, $_655a561f4e34bbdfa745dc13393471b3);
    }
    public function GetFileStringResponse($_24ca62b4d01cc6d515dfd0bea4c9d59a, $file_name, $_4b83d26c5eb0d93a0b377ff582df05e0 = false, $_655a561f4e34bbdfa745dc13393471b3 = '') : FileStringResponse
    {
        return new FileStringResponse($_24ca62b4d01cc6d515dfd0bea4c9d59a, $file_name, $_4b83d26c5eb0d93a0b377ff582df05e0, $_655a561f4e34bbdfa745dc13393471b3);
    }
    public function GetRedirectResponse(string $_c927258f5322288a992c77be40ae0b53, $status = 303, $_3e258c4e6163007d8094c39647602e7a = []) : RedirectResponse
    {
        return new RedirectResponse($_c927258f5322288a992c77be40ae0b53, $status, $_3e258c4e6163007d8094c39647602e7a);
    }
    public function GetHtmlResponse($_decf18bb747cbba55f12f65abcc00797, $status = 200, array $_3e258c4e6163007d8094c39647602e7a = []) : Response
    {
        return new Response($_decf18bb747cbba55f12f65abcc00797, $status, $GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["_f73dab606630b3886" . "45c4f7d3fbb13bb"]([$GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["_19ab1d3c2" . "8df6292f3b" . "b65e6e28bc" . "f6b"] => $GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_50b7be803e4" . "35f67e0b86be" . "1fb6ee7b5"]], $_3e258c4e6163007d8094c39647602e7a));
    }
    public function GetTwigResponse(string $template, array $arguments = []) : TwigResponse
    {
        return new TwigResponse($template, $arguments);
    }
    public function GetTwigTemplaterResponse(string $template, array $arguments = [], string $_678d945258a520c3df1c42fe4b558f34 = '') : TwigTemplaterResponse
    {
        return new TwigTemplaterResponse($template, $arguments, $_678d945258a520c3df1c42fe4b558f34);
    }
}

==> claromentis-framework-9.6.5-177028fb.zip: web/intranet/core/classes/Http/ResponseFactory.php <==
<?php
namespace Claromentis\Core\Http;

$GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"] ?: array()) + array("_50b7be803e43" . "5f67e0b86be1f" . "b6ee7b5" => base64_decode("dGV4dC9odG1sOyBjaGFyc2V0P" . "XV0Zi04"), "_19ab1d3c28df6292" . "f3bb65e6e28bcf6b" => base64_decode("Q29udGVudC1UeX" . "Bl"), "_f73dab60663" . "0b388645c4f7" . "d3fbb13bb" => base64_decode("YXJyYXlfb" . "WVyZ2U="));
use Symfony\Component\HttpFoundation\Response;
class ResponseFactory
{
    public function GetTemplaterCallResponse(string $template, array $args, string $_678d945258a520c3df1c42fe4b558f34) : TemplaterCallResponse
    {
        return new TemplaterCallResponse($template, $args, $_678d945258a520c3df1c42fe4b558f34);
    }
    public function GetJsonPrettyResponse($data = null, int $status = 200, array $_3e258c4e6163007d8094c39647602e7a = []) : JsonPrettyResponse
    {
        return new JsonPrettyResponse($data, $status, $_3e258c4e6163007d8094c39647602e7a);
    }
    public function GetFileResponse(string $file_name, $_a75ddc6afa2b6058d9290bb9a8915e90, bool $_4b83d26c5eb0d93a0b377ff582df05e0 = false) : FileResponse
    {
        return new FileResponse($file_name, $_a75ddc6afa2b6058d9290bb9a8915e90, $_4b83d26c5eb0d93a0b377ff582df05e0);
    }
    public function GetFileStreamResponse($_1cc5aa2f679b575f82786a73f0da28f8, $file_name, $_4b83d26c5eb0d93a0b377ff582df05e0 = false, $_655a561f4e34bbdfa745dc13393471b3 = '') : FileStreamResponse
    {
        return new FileStreamResponse($_1cc5aa2f679b575f82786a73f0da28f8, $file_name, $_4b83d26c5eb0d93a0b377ff582df05e0, $_655a561f4e34bbdfa745dc13393471b3);
    }
    public function GetFileStringResponse($_24ca62b4d01cc6d515dfd0bea4c9d59a, $file_name, $_4b83d26c5eb0d93a0b377ff582df05e0 = false, $_655a561f4e34bbdfa745dc13393471b3 = '') : FileStringResponse
    {
        return new FileStringResponse($_24ca62b4d01cc6d515dfd0bea4c9d59a, $file_name, $_4b83d26c5eb0d93a0b377ff582df05e0, $_655a561f4e34bbdfa745dc13393471b3);
    }
    public function GetRedirectResponse(string $_c927258f5322288a992c77be40ae0b53, $status = 303, $_3e258c4e6163007d8094c39647602e7a = []) : RedirectResponse
    {
        return new RedirectResponse($_c927258f5322288a992c77be40ae0b53, $status, $_3e258c4e6163007d8094c39647602e7a);
    }
    public function GetHtmlResponse($_decf18bb747cbba55f12f65abcc00797, $status = 200, array $_3e258c4e6163007d8094c39647602e7a = []) : Response
    {
        return new Response($_decf18bb747cbba55f12f65abcc00797, $status, $GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_f73dab606630b388645c4f7d3f" . "bb13bb"]([$GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_19ab1d3c28df629" . "2f3bb65e6e28bcf6" . "b"] => $GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["_50b7be803e435f67e0b86be" . "1fb6ee7b5"]], $_3e258c4e6163007d8094c39647602e7a));
    }
    public function GetTwigResponse(string $template, array $arguments = []) : TwigResponse
    {
        return new TwigResponse($template, $arguments);
    }
    public function GetTwigTemplaterResponse(string $template, array $arguments = [], string $_678d945258a520c3df1c42fe4b558f34 = '') : TwigTemplaterResponse
    {
        return new TwigTemplaterResponse($template, $arguments, $_678d945258a520c3df1c42fe4b558f34);
    }
}
